NAME

  systemu

SYNOPSIS

  univeral capture of stdout and stderr and handling of child process pid for windows, *nix, etc.

URIS

  http://github.com/ahoward/systemu
  http://rubyforge.org/projects/codeforpeople/

INSTALL

  gem install systemu

HISTORY
  2.0.0
    - versioning issue.  new gem release.

  1.3.1
    - updates for ruby 1.9.1

  1.3.0
    - move to github

  1.2.0

    - fixed handling of background thread management - needed
      Thread.current.abort_on_exception = true

    - fixed reporting of child pid, it was reported as the parent's pid before

SAMPLES

<%= samples %>
